package types

import (
	"fmt"
	"time"
)

// Sensor ...
type Sensor struct {
	SensorID          string      `json:"sensor_id"`
	SensorName        string      `json:"sensor_name"`
	SensorLocation    string      `json:"sensor_location"`
	WireID            *string     `json:"wire_id"`
	GPIONumber        *string     `json:"gpio_number"`
	SensorModel       SensorModel `json:"sensor_model"`
	SensorEnabled     bool        `json:"sensor_enabled"`
	SensorLastContact time.Time   `json:"sensor_last_contact"`
	DeviceID          string      `json:"device_id"`
	CreationDate      time.Time   `json:"creation_date"`
}

func (s *Sensor) Name() string {
	if s.SensorName != "" {
		return s.SensorName
	} else if *s.WireID != "" {
		return *s.WireID
	}
	return s.SensorID
}

type SensorModel string

const (
	DHT11   SensorModel = "DHT11"
	DHT22               = "DHT22"
	DS18B20             = "DS18B20"
)

// SelectSensorModel converts a string into a constant
func SelectSensorModel(model string) (SensorModel, error) {
	switch model {
	case "DHT11":
		return DHT11, nil
	case "DHT22":
		return DHT22, nil
	case "DS18B20":
		return DS18B20, nil
	default:
		return "", fmt.Errorf("Sensor Model %v currently not supported", model)
	}
}
